@@ -2,6 +2,10 @@
 
 from __future__ import absolute_import, unicode_literals
 
+# Import the fastest implementation of
+# pickle package. This should be removed
+# when python3 come the unique supported
+# python version
 try:
     import cPickle as pickle
 except ImportError:
@@ -12,8 +16,10 @@ import warnings
 
 try:
     from django.utils.encoding import smart_bytes
+    from django.utils.encoding import smart_text
 except ImportError:
     from django.utils.encoding import smart_str as smart_bytes
+    from django.utils.encoding import smart_unicode as smart_text
 
 from django.utils.datastructures import SortedDict
 from django.core.exceptions import ImproperlyConfigured
@@ -24,16 +30,13 @@ try:
 except ImportError:
     DEFAULT_TIMEOUT = object()
 
-from redis import Redis
-from redis.exceptions import ConnectionError, ResponseError
-from redis.connection import (Connection,
-                              DefaultParser,
-                              UnixDomainSocketConnection)
+from redis.exceptions import ConnectionError
+from redis.exceptions import ResponseError
 
-from ..util import CacheKey, load_class, integer_types
-from ..exceptions import ConnectionInterrupted
-
-from .. import pool
+from redis_cache.util import CacheKey
+from redis_cache.util import integer_types
+from redis_cache.exceptions import ConnectionInterrupted
+from redis_cache import pool
 
 
 class DefaultClient(object):
@@ -381,6 +384,19 @@ class DefaultClient(object):
         return self._incr(key=key, delta=-delta, version=version,
                           client=client)
 
+    def ttl(self, key, version=None, client=None):
+        """
+        Executes TTL redis command and return the "time-to-live" of specified key.
+        If key is a non volatile key, it returns None.
+        """
+        if client is None:
+            client = self.get_client(write=False)
+
+        key = self.make_key(key, version=version)
+        if not client.exists(key):
+            return 0
+        return client.ttl(key)
+
     def has_key(self, key, version=None, client=None):
         """
         Test if key exists.
@@ -395,13 +411,42 @@ class DefaultClient(object):
         except ConnectionError:
             raise ConnectionInterrupted(connection=client)
 
-    def keys(self, search, client=None):
+    def iter_keys(self, search, itersize=None, client=None, version=None):
+        """
+        Same as keys, but uses redis >= 2.8 cursors
+        for make memory efficient keys iteration.
+        """
+
         if client is None:
             client = self.get_client(write=False)
 
-        pattern = self.make_key(search)
+        pattern = self.make_key(search, version=version)
+        cursor = b"0"
+
+        while True:
+            cursor, data = client.scan(cursor, match=pattern, count=itersize)
+
+            for item in data:
+                item = smart_text(item)
+                yield item.split(":", 2)[2]
+
+            if cursor == b"0":
+                break
+
+    def keys(self, search, version=None, client=None):
+        """
+        Execute KEYS command and return matched results.
+        Warning: this can return huge number of results, in
+        this case, it strongly recommended use iter_keys
+        for it.
+        """
+
+        if client is None:
+            client = self.get_client(write=False)
+
+        pattern = self.make_key(search, version=version)
         try:
-            encoding_map = [k.decode('utf-8') for k in client.keys(pattern)]
+            encoding_map = [smart_text(k) for k in client.keys(pattern)]
             return [k.split(":", 2)[2] for k in encoding_map]
         except ConnectionError:
             raise ConnectionInterrupted(connection=client)
